==> haskell-stm-chans-3.0.0.4-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
key: stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
license: BSD-3-Clause
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
author: wren gayle romano, Thomas DuBuisson
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
abi: 95b0b718bbd953252bfb86d62efe20ac
exposed: True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
import-dirs: /usr/lib/ghc-8.4.3/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
depends:
    base-4.11.1.0 stm-2.4.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-chans-3.0.0.4-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-HYjkOAxusm59Rsr7teGCcb
key: stm-chans-3.0.0.4-HYjkOAxusm59Rsr7teGCcb
license: BSD-3-Clause
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
author: wren gayle romano, Thomas DuBuisson
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
abi: 10e1c0f84a8d353adafd6e6bf44ca59b
exposed: True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
import-dirs: /usr/lib/ghc-8.6.1/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-HYjkOAxusm59Rsr7teGCcb
depends:
    base-4.12.0.0 stm-2.5.0.0
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
